text

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Text

func Text(p TextProps, value string) templ.Component

Text renders plain copy in the chosen semantic tag.

Types

type TextProps

type TextProps struct {
	Class string
	// Tag — p, span, small, code, kbd, blockquote, ins, del, …; defaults to p
	Tag   string
	Attrs templ.Attributes
}

TextProps configures typography element and classes.

Jump to